@@ -16,13 +16,13 @@
 This module is able to take a dotted name of any class and display
 documentation for it.
 
-$Id: codemodule.py 113308 2010-06-10 01:09:36Z srichter $
 """
+from zope.testing.cleanup import addCleanUp
 __docformat__ = 'restructuredtext'
 
 import zope.component
 from zope.i18nmessageid import ZopeMessageFactory as _
-from zope.interface import implements
+from zope.interface import implementer
 
 from zope.app.apidoc.interfaces import IDocumentationModule
 from zope.app.apidoc.classregistry import safe_import
@@ -30,14 +30,14 @@ from zope.app.apidoc.codemodule.interfaces import IAPIDocRootModule
 from zope.app.apidoc.codemodule.module import Module
 
 
+@implementer(IDocumentationModule)
 class CodeModule(Module):
     """Represent the code browser documentation root"""
-    implements(IDocumentationModule)
 
-    # See zope.app.apidoc.interfaces.IDocumentationModule
+    #: The title.
     title = _('Code Browser')
 
-    # See zope.app.apidoc.interfaces.IDocumentationModule
+    #: The description.
     description = _("""
     This module allows you to get an overview of the modules and classes
     defined in the Zope 3 framework and its supporting packages. There are
@@ -59,6 +59,7 @@ class CodeModule(Module):
     interface that requires a method or attribute to be implemented and the
     permissions required to access it.
     """)
+
     def __init__(self):
         """Initialize object."""
         super(CodeModule, self).__init__(None, '', None, False)
@@ -68,34 +69,60 @@ class CodeModule(Module):
         """Setup module and class tree."""
         if self.__isSetup:
             return
+        self.__isSetup = True
+        self._children = {}
         for name, mod in zope.component.getUtilitiesFor(IAPIDocRootModule):
             module = safe_import(mod)
             if module is not None:
                 self._children[name] = Module(self, name, module)
-        self.__isSetup = True
+
+        # And the builtins are always available, since that's the
+        # most common root module linked to from docs.
+        builtin_module = safe_import('__builtin__') or safe_import('builtins')
+        assert builtin_module is not None
+        builtin_module = Module(self, builtin_module.__name__, builtin_module)
+        # Register with both names for consistency in the tests between Py2 and
+        # Py3
+        self._children['builtins'] = self._children['__builtin__'] = (
+            builtin_module)
+
+    def withParentAndName(self, parent, name):
+        located = type(self)()
+        located.__parent__ = parent
+        located.__name__ = name
+        self.setup()
+        located._children = {name: module.withParentAndName(located, name)
+                             for name, module in self._children.items()}
+        located.__isSetup = True
+        return located
 
     def getDocString(self):
-        """See Module class."""
         return _('Zope 3 root.')
 
     def getFileName(self):
-        """See Module class."""
         return ''
 
     def getPath(self):
-        """See Module class."""
         return ''
 
     def isPackage(self):
-        """See Module class."""
         return True
 
     def get(self, key, default=None):
-        """See zope.container.interfaces.IReadContainer."""
         self.setup()
         return super(CodeModule, self).get(key, default)
 
     def items(self):
-        """See zope.container.interfaces.IReadContainer."""
         self.setup()
         return super(CodeModule, self).items()
+
+
+def _cleanUp():
+    from zope.component import getGlobalSiteManager
+    code = getGlobalSiteManager().queryUtility(
+        IDocumentationModule, name='Code')
+    if code is not None:
+        code.__init__()
+
+
+addCleanUp(_cleanUp)
