@@ -13,18 +13,24 @@
 ##############################################################################
 """zope.app.apidoc common test related classes/functions/objects.
 
-$Id: testing.py 113308 2010-06-10 01:09:36Z srichter $
 """
+import zope.app.apidoc
+from zope.app.wsgi.testlayer import BrowserLayer
+from zope.testbrowser.wsgi import TestBrowserLayer
 
-__docformat__ = "reStructuredText"
 
-import os
-from zope.app.testing.functional import ZCMLLayer
+class _BrowserLayer(TestBrowserLayer, BrowserLayer):
+    pass
 
-APIDocNoDevModeLayer = ZCMLLayer(
-    os.path.join(os.path.split(__file__)[0], 'ftesting-base.zcml'),
-    __name__, 'APIDocNoDevModeLayer', allow_teardown=True)
 
-APIDocLayer = ZCMLLayer(
-    os.path.join(os.path.split(__file__)[0], 'ftesting.zcml'),
-    __name__, 'APIDocLayer', allow_teardown=True)
+APIDocNoDevModeLayer = _BrowserLayer(
+    zope.app.apidoc,
+    name="APIDocNoDevModeLayer",
+    zcml_file='ftesting-base.zcml',
+    allowTearDown=True)
+
+APIDocLayer = _BrowserLayer(
+    zope.app.apidoc,
+    name="APIDocLayer",
+    features=['static-apidoc'],
+    allowTearDown=True)
